@@ -13,3 +13,6 @@ if __name__ == '__main__':
     pattern = { 'cmd' :'TEST_PATTERN' }
     res = client.send(pattern, None)
     print(res)
+    pattern = { 'cmd' :'test_decorator' }
+    res = client.send(pattern, 'this is ok')
+    print(res)
